==> jmb.fax-0.2.tar.gz: jmb.fax-0.2/jmb/fax/management/commands/batch_fax.py <==
from optparse import make_option
import csv
import commands
import time

from django.core.management.base import BaseCommand
from django.conf import settings
from django.core.files import File
from django.core.files.base import ContentFile

from jmb.fax.models import Fax
from django.contrib.auth.models import User
from jumbo.core.files.storage import JumboStorage

#PATH_FILE = '/home/marco/src/siti/thunder/officenew.thundersystems.it/office_thunder/files/'

class Command(BaseCommand):
    help = "Send Batch Faxes."

    option_list = BaseCommand.option_list + (
        make_option('-n', '--fax_numbers', dest='fax_numbers',
                    help='List all fax Numbers'),
        make_option('-f', '--fax_file', dest='fax_file',
                    help='List all fax Numbers'),
        make_option('-d', '--device', dest='device',
                    help='Device'),
        make_option('-s', '--subject', dest='subject',
                    help='Subject'),
    )

    output_transaction = True

    def handle(self, **options):
        if not options['fax_numbers'] or not options['fax_file'] or not options['device']:
            print "All argument (-f -n -d) are required"
            return

        file_numbers = csv.reader(open(options['fax_numbers']), delimiter=';')
        u = User.objects.get(username='admin')

        f = open(options['fax_file'], 'r')
        js = JumboStorage()
        real_file_name = js.save('fax/fax_batch.pdf', ContentFile(f.read()))

        for i, r in enumerate(file_numbers):
            anagr_name   = r[0]
            anagr_number = r[1]

            fax = Fax()
            fax.recipient = anagr_name
            fax.recipient_number = anagr_number
            fax.submitter = u
            fax.read = 1
            fax.status = 3
            fax.subject = options['subject']
            fax.device = options['device']
            fax.file = 'fax/%s' % real_file_name
            fax.save()

            # Converto, per sicurezza, il file pdf in un a4 verticale
            # Infatti, quando si scanerrizza dalla stampante capita che il pdf creato
            # sia verticale ma con la page size a 842x596, invece di 596x842, e questo
            # fa si che il fax non venga spedito
            #
            info = {
                'path'       : '/usr/bin/sendfax',
                'start_time' : 'now',
                'fax_number' : anagr_number,
                'file_name'  : options['fax_file'], #'/tmp/%s' % (ps_tmp_file,),
                'priority'   : 127,
                'device'     : options['device'] + "@127.0.0.1"
                }

            cmd = "%(path)s -a %(start_time)s -P %(priority)s -n -s a4 -D -d %(fax_number)s -h %(device)s %(file_name)s"
            cmd = cmd % info

            status, output = commands.getstatusoutput(cmd)
            fax.job = output.split()[3]
            fax.save()
            time.sleep(60)

==> jmb.fax-0.6.tar.gz: jmb.fax-0.6/jmb/fax/management/commands/batch_fax.py <==
from __future__ import unicode_literals

from optparse import make_option
import csv
try:
    from subprocess import getstatusoutput
except ImportError:
    from commands import getstatusoutput
import time

from django.core.management.base import BaseCommand
from django.conf import settings
from django.core.files import File
from django.core.files.base import ContentFile

from jmb.fax.models import Fax
from django.contrib.auth.models import User
from jumbo.core.files.storage import JumboStorage

#PATH_FILE = '/home/marco/src/siti/thunder/officenew.thundersystems.it/office_thunder/files/'

class Command(BaseCommand):
    help = "Send Batch Faxes."

    option_list = BaseCommand.option_list + (
        make_option('-n', '--fax_numbers', dest='fax_numbers',
                    help='List all fax Numbers'),
        make_option('-f', '--fax_file', dest='fax_file',
                    help='List all fax Numbers'),
        make_option('-d', '--device', dest='device',
                    help='Device'),
        make_option('-s', '--subject', dest='subject',
                    help='Subject'),
    )

    output_transaction = True

    def handle(self, **options):
        if not options['fax_numbers'] or not options['fax_file'] or not options['device']:
            print("All argument (-f -n -d) are required")
            return

        file_numbers = csv.reader(open(options['fax_numbers']), delimiter=';')
        u = User.objects.get(username='admin')

        f = open(options['fax_file'], 'r')
        js = JumboStorage()
        real_file_name = js.save('fax/fax_batch.pdf', ContentFile(f.read()))

        for i, r in enumerate(file_numbers):
            anagr_name = r[0]
            anagr_number = r[1]

            fax = Fax()
            fax.recipient = anagr_name
            fax.recipient_number = anagr_number
            fax.submitter = u
            fax.read = 1
            fax.status = 3
            fax.subject = options['subject']
            fax.device = options['device']
            fax.file = 'fax/%s' % real_file_name
            fax.save()

            # Converto, per sicurezza, il file pdf in un a4 verticale
            # Infatti, quando si scanerrizza dalla stampante capita che il pdf creato
            # sia verticale ma con la page size a 842x596, invece di 596x842, e questo
            # fa si che il fax non venga spedito
            #
            info = {
                'path': '/usr/bin/sendfax',
                'start_time': 'now',
                'fax_number': anagr_number,
                'file_name': options['fax_file'],  # '/tmp/%s' % (ps_tmp_file,),
                'priority': 127,
                'device': options['device'] + "@127.0.0.1"
            }

            cmd = "%(path)s -a %(start_time)s -P %(priority)s -n -s a4 -D -d %(fax_number)s -h %(device)s %(file_name)s"
            cmd = cmd % info
            status, output = subprocess.getstatusoutput(cmd)
            fax.job = output.split()[3]
            fax.save()
            time.sleep(60)
